@@ -2,7 +2,7 @@
 /*
  * gtk_blob.cc
  * Copyright (C) 1999-2003 by John Heidemann
- * $Id: gtk_blob.cc,v 1.59 2004/06/06 04:51:25 johnh Exp $
+ * $Id: gtk_blob.cc,v 1.63 2004/12/17 19:59:13 johnh Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License,
@@ -105,8 +105,9 @@ GtkLabel *gtk_blob::info_text_label_ = 0;
 //
 gtk_blob_splash *gtk_blob::splash_ = NULL;
 gtk_blob_base *gtk_blob::base_ = NULL;
+GList *gtk_blob::icon_pixbufs_glist_ = NULL;
 //
-gtk_blob_conf_int *gtk_blob::size_divisor_conf_ = NULL;
+gtk_blob_conf_double *gtk_blob::size_mem_to_screen_scale_conf_ = NULL;
 gtk_blob_conf_double *gtk_blob::check_interval_conf_ = NULL;
 explicit_change_tracking<double> gtk_blob::check_interval_seconds_(2.0);
 
@@ -1015,8 +1016,8 @@ gtk_blob::init_conf()
 				       O_("/apps/lavaps/sticky"), 
 				       GTK_CHECK_MENU_ITEM(how_menu[9].widget));
 	// some non-GUI things
-	size_divisor_conf_ = new gtk_blob_conf_int(process_view::size_divisor_address(),
-						   30, 1, 100000, O_("/apps/lavaps/size_divisor"));
+	size_mem_to_screen_scale_conf_ = new gtk_blob_conf_double(process_view::size_mem_to_screen_scale_address(),
+						   1.0, 1e-8, 1e8, O_("/apps/lavaps/size_mem_to_screen_scale"));
 	check_interval_conf_ = new gtk_blob_conf_double(check_interval_seconds_.address(),
 						       2.0, 0.01, 10.0,
 						       O_("/apps/lavaps/check_interval"));
@@ -1033,6 +1034,25 @@ gtk_blob::init_ticker()
 				     NULL);
 }
 
+// static
+void
+gtk_blob::init_icons()
+{
+	extern const char **icon_xpms[];
+	const char ***xpms = &icon_xpms[0];
+	assert(icon_pixbufs_glist_ == NULL);
+	int num_icons = 0;
+	while (*xpms != NULL) {
+		GdkPixbuf *pixbuf = gdk_pixbuf_new_from_xpm_data(*xpms);
+		assert(pixbuf != NULL);
+		icon_pixbufs_glist_ = g_list_append(icon_pixbufs_glist_, pixbuf);
+		xpms++;
+		num_icons++;
+	};
+	assert(num_icons > 0);
+	gtk_window_set_default_icon_list(icon_pixbufs_glist_);
+}
+
 // static
 void
 gtk_blob::init(int argc, char **argv)
@@ -1050,6 +1070,7 @@ gtk_blob::init(int argc, char **argv)
 	program_ = gnome_program_init(O_("lavaps"), "2.0",
 				  LIBGNOMEUI_MODULE,
 	                          argc, argv,
+				  GNOME_PARAM_POPT_TABLE, popt_options,
 				  GNOME_PARAM_NONE);
 	app_ = gnome_app_new(O_("lavaps"), _("LavaPS"));
 	/*
@@ -1068,6 +1089,7 @@ gtk_blob::init(int argc, char **argv)
 			   GTK_SIGNAL_FUNC(gtk_main_quit),
 			   NULL);
 
+	init_icons();
 
 	init_canvas();
 	assert(canvas_w_ != NULL);
@@ -1083,7 +1105,7 @@ gtk_blob::init(int argc, char **argv)
 
 	if (lava_default_geometry) {
 		if (!gtk_window_parse_geometry(GTK_WINDOW(app_), lava_default_geometry))
-			cerr << _("warning: could not parse -geometry option: ") << lava_default_geometry << endl;
+			cerr << _("warning: could not parse --geometry option: ") << lava_default_geometry << endl;
 	};
 
 	init_ticker();
@@ -1276,7 +1298,7 @@ gtk_blob::set_hsb(double h, double s, double b)
 void
 gtk_blob::size_divisor_commit()
 {
-	size_divisor_conf_->to_conf();
+	size_mem_to_screen_scale_conf_->to_conf();
 }
 
 #endif /* USE_GTK_BLOB */
